==> tutti-ui-swing-0.2.5-sources.jar: fr/ifremer/tutti/ui/swing/util/HydrologicCaracteristicUtil.java <==

package fr.ifremer.tutti.ui.swing.util;

/*
 * #%L
 * Tutti :: UI
 * $Id: HydrologicCaracteristicUtil.java 132 2012-12-30 19:39:00Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-0.2.5/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/HydrologicCaracteristicUtil.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.referential.Caracteristic;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 0.3
 */
public class HydrologicCaracteristicUtil {

    public enum Type {
        START,
        END,
        AVERAGE
    }

    public static String getGlobalName(String name) {
        if (name.charAt(name.length() - 2) == '_') {
            name = name.substring(0, name.length() - 2);
        }
        return name;
    }

    public static Caracteristic createGlobalCaracteristic(String name, Caracteristic toClone) {
        Caracteristic caracteristic = new Caracteristic();
        caracteristic.setName(name);
        caracteristic.setId(name);
        if (toClone != null) {
            caracteristic.setCategory(toClone.getCategory());
            caracteristic.setBooleanType(toClone.isBooleanType());
            caracteristic.setNumberType(toClone.isNumberType());
            caracteristic.setQualitativeType(toClone.isQualitativeType());
            caracteristic.setQualitativeValue(toClone.getQualitativeValue());
            caracteristic.setTextType(toClone.isTextType());
            caracteristic.setUnit(toClone.getUnit());
        }
        return caracteristic;
    }

    public static Type getTypeOfCaracteristic(Caracteristic caracteristic) {
        String name = caracteristic.getName();
        Type result = null;
        if (name.charAt(name.length() - 2) == '_') {
            char lastChar = name.charAt(name.length() - 1);
            switch (lastChar) {
                case 'S':
                    result = Type.START;
                    break;
                case 'E':
                    result = Type.END;
                    break;
                case 'A':
                    result = Type.AVERAGE;
            }
        }
        return result;
    }
}

==> tutti-ui-swing-0.3-sources.jar: fr/ifremer/tutti/ui/swing/util/HydrologicCaracteristicUtil.java <==

package fr.ifremer.tutti.ui.swing.util;

/*
 * #%L
 * Tutti :: UI
 * $Id: HydrologicCaracteristicUtil.java 165 2013-01-10 13:42:09Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-0.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/util/HydrologicCaracteristicUtil.java $
 * %%
 * Copyright (C) 2012 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.referential.Caracteristic;

/**
 * @author kmorin <kmorin@codelutin.com>
 * @since 0.3
 */
public class HydrologicCaracteristicUtil {

    public enum Type {
        START,
        END,
        AVERAGE
    }

    public static String getGlobalName(String name) {
        if (name.charAt(name.length() - 2) == '_') {
            name = name.substring(0, name.length() - 2);
        }
        return name;
    }

    public static Caracteristic createGlobalCaracteristic(String name, Caracteristic toClone) {
        Caracteristic caracteristic = new Caracteristic();
        caracteristic.setName(name);
        caracteristic.setId(name);
        if (toClone != null) {
            caracteristic.setCategory(toClone.getCategory());
            caracteristic.setPrecision(toClone.getPrecision());
            caracteristic.setMaximumNumberDecimals(toClone.getMaximumNumberDecimals());
            caracteristic.setSignifFiguresNumber(toClone.getSignifFiguresNumber());
            caracteristic.setNumberType(toClone.isNumberType());
            caracteristic.setQualitativeType(toClone.isQualitativeType());
            caracteristic.setQualitativeValue(toClone.getQualitativeValue());
            caracteristic.setUnit(toClone.getUnit());
        }
        return caracteristic;
    }

    public static Type getTypeOfCaracteristic(Caracteristic caracteristic) {
        String name = caracteristic.getName();
        Type result = null;
        if (name.charAt(name.length() - 2) == '_') {
            char lastChar = name.charAt(name.length() - 1);
            switch (lastChar) {
                case 'S':
                    result = Type.START;
                    break;
                case 'E':
                    result = Type.END;
                    break;
                case 'A':
                    result = Type.AVERAGE;
            }
        }
        return result;
    }
}
